#!/usr/bin/env python

#
# Copyright (C) 2006 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import os.path
import locale
import gettext
import optparse
import installer
from config import *

from stacaccli.common import logger
from stacaccli.common import shvar
from stacaccli.common.config import *

def main (args):
    locale.setlocale (locale.LC_ALL, "")
    gettext.install (PACKAGE, os.path.join (DATADIR, "locale"))

    parser = optparse.OptionParser (version = "%prog " + VERSION,
                                    usage = _("%prog [<options>] <device>"))

    parser.add_option ("--repository",
                       dest = "repo",
                       help = _("Retrieve the image from the supplied URL"),
                       metavar = _("URL"))
    parser.add_option ("--image",
                       dest = "image",
                       help = _("Install the image with the supplied name"),
                       metavar = _("NAME"))
    parser.add_option ("--verbose",
                       action = "store_true",
                       dest = "verbose_output",
                       default = False,
                       help = _("Display verbose messages"))
    parser.add_option ("--force",
                       action = "store_true",
                       dest = "force",
                       default = False,
                       help = _("Do not prompt for confirmation"))

    (options, args) = parser.parse_args (args)

    if len (args) != 1:
        parser.print_usage (sys.stderr)
        sys.exit (1)

    device_path = args[0]

    logger.set_verbose_output (options.verbose_output)

    conf = shvar.Config ()

    if not options.repo:
        if not conf.repository_url:
            raise installer.InstallerError (_("No URL for image repository supplied"))
        options.repo = conf.repository_url

    if not options.image:
        if not conf.image:
            raise installer.InstallerError (_("No image name supplied"))
        options.image = conf.image_name
    
    installer.Install (options.repo, options.image, device_path, options.force).run ()
